@@ -1,5 +1,5 @@
 """
-TalkLabs Python SDK v2.1.5
+TalkLabs Python SDK v2.1.6
 ---------------------------
 SDK minimalista para TTS streaming com sessões persistentes.
 
@@ -194,11 +194,11 @@ class StreamingSession:
 
 class TalkLabsClient:
     """
-    Cliente TalkLabs para síntese de voz com streaming Redis.
+    Cliente TalkLabs para síntese de voz com streaming WebSocket.
 
     Features:
         - Streaming ultra-low latency (~200-500ms)
-        - Sessões persistentes (reutilização de conexão)
+        - Sessões persistentes (reutilização de conexão WebSocket)
         - Keep-alive automático (ping/pong)
         - API unificada (stream_text)
 
@@ -266,8 +266,8 @@ class TalkLabsClient:
         - Erro de conexão
 
         Args:
-            voice: ID da voz TalkLabs (ex: "adam_rocha", "adam_rocha")
-            language: Código do idioma ("pt", "en", etc)
+            voice: ID da voz TalkLabs (ex: "adam_rocha", "maria_sofia")
+            language: Código do idioma (pt, en, es, fr, de, it, pl, etc)
             speed: Velocidade de reprodução (0.5-2.0)
             voice_settings: Configurações opcionais de voz
             ping_interval: Intervalo entre pings (segundos, padrão: 20)
@@ -291,11 +291,11 @@ class TalkLabsClient:
             >>> # Fecha quando terminar
             >>> await session.close()
         """
-        # Conecta ao endpoint de streaming Redis
+        # Conecta ao endpoint de streaming WebSocket
         base = self.base_url.replace('https', 'wss').replace('http', 'ws')
         ws_url = f"{base}/v1/text-to-speech/{voice}/stream-redis"
 
-        logger.info("[TalkLabs] Criando sessão persistente: %s", ws_url)
+        logger.info("[TalkLabs] Criando sessão WebSocket persistente: %s", ws_url)
 
         try:
             # Conecta ao WebSocket com keep-alive configurável
@@ -341,7 +341,7 @@ class TalkLabsClient:
         voice_settings: Optional[VoiceSettings] = None,
     ) -> AsyncIterator[bytes]:
         """
-        Sintetiza texto usando streaming Redis SEM sessão persistente.
+        Sintetiza texto usando streaming WebSocket SEM sessão persistente.
 
         Este método cria uma nova conexão WebSocket, sintetiza o texto,
         e fecha a conexão automaticamente. Ideal para sínteses únicas.
@@ -352,7 +352,7 @@ class TalkLabsClient:
         Args:
             text: Texto para sintetizar
             voice: ID da voz (ex: "adam_rocha")
-            language: Código do idioma (padrão: "pt")
+            language: Código do idioma (pt, en, es, fr, de, it, pl, etc)
             speed: Velocidade de reprodução (0.5-2.0)
             voice_settings: Configurações opcionais de voz
 
